@@ -4,9 +4,11 @@ def sasa_frames_iter(md_universe, max_frame, chunk_size, step, selector, vdw_map
 
     atom_selection = None
     try:      
-        atom_selection = md_universe.select_atoms(selector)
+        noH_selector = f"({selector}) and not name H*"
+        atom_selection = md_universe.select_atoms(noH_selector)
+    
     except Exception as e:
-        print(f"Incorrrect atom selector \"{selector}\"")
+        print(f"Incorrrect atom selector \"{noH_selector}\"")
         print(e)
         exit(1)
     
@@ -16,8 +18,7 @@ def sasa_frames_iter(md_universe, max_frame, chunk_size, step, selector, vdw_map
     segids    = atom_selection.segids
    
     if len(atom_selection.names) == 0:
-        raise ValueError(f"Selector \"{selector}\" returned an empty atom set!")
-
+        raise ValueError(f"Selector \"{noH_selector}\" returned an empty atom set!")
 
     trajectory = md_universe.trajectory
     if max_frame is None:
@@ -50,7 +51,7 @@ def sasa_frames_iter(md_universe, max_frame, chunk_size, step, selector, vdw_map
     return ( log, _iter(), max_frame )
 # a thread-based function recevieving input tuple iterator and calling ccmap
 def sasa_frame_task(*_args):
-    args=_args[0]    
+    args=_args[0]
     data = ccmap.sasa_multi_mda(*args[:6], probe=args[6], hres=args[7])
     
     return data
